Crate tokio_tungstenite_wasm

Crate tokio_tungstenite_wasm 

Re-exports

pub use error::Error;
pub use error::Result;

Modules

error
Error handling.

Structs

Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
CloseFrame
A struct representing the close command.
Utf8Bytes
Utf8 payload.
WebSocketStream

Enums

CloseCode
Status code used to indicate why an endpoint is closing the WebSocket connection.
Connector
A connector that can be used when establishing connections, allowing to control whether native-tls or rustls is used to create a TLS connection. Or TLS can be disabled with the Plain variant.
Message
An enum representing the various forms of a WebSocket message.

Functions

connect
connect_custom_tls
connect_with_protocols