Crate tokio_tungstenite_wasm
tokio_
tungstenite_
wasm
0.8.2
All Items
Crate Items
Re-exports
Modules
Structs
Enums
Functions
Crate
tokio_
tungstenite_
wasm
Re-exports

pub use error::
Error
;
pub use error::
Result
;
Modules

error
Error handling.
Structs

Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
Close
Frame
A struct representing the close command.
Utf8
Bytes
Utf8 payload.
WebSocket
Stream
Enums

Close
Code
Status code used to indicate why an endpoint is closing the WebSocket connection.
Connector
A connector that can be used when establishing connections, allowing to control whether
native-tls
or
rustls
is used to create a TLS connection. Or TLS can be disabled with the
Plain
variant.
Message
An enum representing the various forms of a WebSocket message.
Functions

connect
connect_
custom_
tls
connect_
with_
protocols